@@ -30,8 +30,7 @@ fi
 
 # we want to expand --exclude to several arguments
 # shellcheck disable=SC2086
-if "${BUILDDIR}"/dist/bin/run-mozilla.sh \
-   "${BUILDDIR}"/_virtualenvs/build/bin/python3 -u \
+if python3 -u \
    "${SRCDIR}"/jit-test/jit_test.py \
    --format=automation \
    --no-slow \
